@@ -2,9 +2,9 @@ package File::UnixAuth::Result;
 
 use namespace::autoclean;
 
-use Moo;
-use File::DataClass::Constants;
+use File::DataClass::Constants qw( FALSE );
 use File::DataClass::Functions qw( is_member );
+use Moo;
 
 extends q(File::DataClass::Result);
 
@@ -98,7 +98,7 @@ Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2014 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
