@@ -2,90 +2,75 @@ package File::UnixAuth::Storage;
 
 use namespace::autoclean;
 
+use File::DataClass::Constants qw( FALSE NUL SPC TRUE );
 use Moo;
-use MooX::Augment -class;
-use File::DataClass::Constants;
-use Lingua::EN::NameParse;
 
 extends q(File::DataClass::Storage);
 
-augment '_read_file' => sub {
-   my ($self, $rdr) = @_;
+# Private functions
+my $_original_order = sub {
+   my ($hash, $lhs, $rhs) = @_;
 
-   $self->encoding and $rdr->encoding( $self->encoding );
-
-   return $self->_read_filter( [ $rdr->chomp->getlines ] );
+   # New elements will be  added at the end
+   exists $hash->{ $lhs }->{_order_by} or return  1;
+   exists $hash->{ $rhs }->{_order_by} or return -1;
+   return $hash->{ $lhs }->{_order_by} <=> $hash->{ $rhs }->{_order_by};
 };
 
-augment '_write_file' => sub {
-   my ($self, $wtr, $data) = @_;
+my $_parse_name = sub {
+   my $full_name = shift; $full_name or return {};
 
-   $self->encoding and $wtr->encoding( $self->encoding );
+   my ($first_name, $last_name) = split SPC, $full_name, 2;
 
-   $wtr->println( @{ $self->_write_filter( $data ) } );
-   return $data;
+   return { first_name => $first_name, last_name => $last_name };
 };
 
 # Private methods
-sub _deflate {
+my $_deflate = sub {
+   my ($self, $hash, $id) = @_; my $attr = $hash->{ $id }; my $gecos = NUL;
+
+   exists $attr->{members   }
+      and $attr->{members   } = join ',', @{ $attr->{members   } || [] };
+   exists $attr->{first_name} and $gecos .=  $attr->{first_name} // NUL;
+   exists $attr->{last_name } and $gecos .=  $attr->{last_name }
+                                       ? SPC.$attr->{last_name }  : NUL;
+
+   if ($attr->{location} or $attr->{work_phone} or $attr->{home_phone}) {
+      $gecos .= ','.($attr->{location  } // NUL);
+      $gecos .= ','.($attr->{work_phone} // NUL);
+      $gecos .= ','.($attr->{home_phone} // NUL);
+   }
+
+   $gecos and $attr->{gecos} = $gecos;
+   return;
+};
+
+my $_inflate = sub {
    my ($self, $hash, $id) = @_; my $attr = $hash->{ $id };
 
-   if (exists $attr->{members}) {
-       $attr->{members} = join q(,), @{ $attr->{members} || [] };
-   }
-
-   if (exists $attr->{first_name}) {
-      my $gecos = $attr->{first_name} || NUL;
-
-      $gecos .= $attr->{last_name} ? SPC.$attr->{last_name} : NUL;
-
-      if ($attr->{location} or $attr->{work_phone} or $attr->{home_phone}) {
-         $gecos .= q(,).($attr->{location  } || q(?));
-         $gecos .= q(,).($attr->{work_phone} || q(?));
-         $gecos .= q(,).($attr->{home_phone} || q(?));
-      }
-
-      $attr->{gecos} = $gecos;
-   }
-
-   return;
-}
-
-sub _inflate {
-   my ($self, $hash, $id, $name_parser) = @_; my $attr = $hash->{ $id };
-
-   if (exists $attr->{members}) {
-       $attr->{members} = [ split m{ , }mx, $attr->{members} || NUL ];
-   }
+   exists $attr->{members}
+      and $attr->{members} = [ split m{ , }mx, $attr->{members} // NUL ];
 
    if (exists $attr->{gecos}) {
-      my %names  = ( surname_1 => NUL, );
-      my @fields = qw(full_name location work_phone home_phone);
+      my @fields = qw( full_name location work_phone home_phone );
 
-      @{ $attr }{ @fields } = split m{ , }mx, $attr->{gecos} || NUL;
+      @{ $attr }{ @fields } = split m{ , }mx, $attr->{gecos} // NUL;
 
-      # Weird logic is correct from L::EN::NP POD
-      if ($attr->{full_name}
-          and not $name_parser->parse( $attr->{full_name} )) {
-         %names = $name_parser->components;
-      }
-      else { $names{given_name_1} = $attr->{full_name} || $id }
+      my $names  = $_parse_name->( $attr->{full_name} );
 
-      $attr->{first_name} = $names{given_name_1};
-      $attr->{last_name } = $names{surname_1   };
+      $attr->{first_name} = $names->{first_name} // NUL;
+      $attr->{last_name } = $names->{last_name } // NUL;
       delete $attr->{full_name}; delete $attr->{gecos};
    }
 
    return;
-}
+};
 
-sub _read_filter {
+my $_read_filter = sub {
    my ($self, $buf) = @_; my $hash = {}; my $order = 0;
 
    my $source_name = $self->schema->source_name;
    my $fields      = $self->schema->source->attributes;
-   my %args        = ( force_case => 1, lc_prefix => 1 );
-   my $name_parser = Lingua::EN::NameParse->new( %args );
 
    for my $line (@{ $buf || [] }) {
       my ($id, @rest) = split m{ : }mx, $line; my %attr = ();
@@ -93,42 +78,50 @@ sub _read_filter {
       @attr{ @{ $fields } } = @rest;
       $attr{ _order_by    } = $order++;
       $hash->{ $id } = \%attr;
-      $self->_inflate( $hash, $id, $name_parser );
+      $self->$_inflate( $hash, $id );
    }
 
    return { $source_name => $hash };
-}
+};
 
-sub _write_filter {
+my $_write_filter = sub {
    my ($self, $data) = @_; my $buf = [];
 
    my $source_name = $self->schema->source_name;
    my $fields      = $self->schema->source->attributes;
    my $hash        = $data->{ $source_name };
 
-   $source_name eq q(passwd) and $fields = [ @{ $fields }[ 0 .. 5 ] ];
+   $source_name eq 'passwd' and $fields = [ @{ $fields }[ 0 .. 5 ] ];
 
-   for my $id (sort { __original_order( $hash, $a, $b ) } keys %{ $hash }) {
-      $self->_deflate( $hash, $id );
+   for my $id (sort { $_original_order->( $hash, $a, $b ) } keys %{ $hash }) {
+      $self->$_deflate( $hash, $id );
 
       my $attr = $hash->{ $id }; delete $attr->{_order_by};
-      my $line = join q(:), map { $attr->{ $_ } // NUL } @{ $fields };
+      my $line = join ':', map { $attr->{ $_ } // NUL } @{ $fields };
 
       push @{ $buf }, "${id}:${line}";
    }
 
    return $buf;
+};
+
+# Public methods
+sub read_from_file {
+   my ($self, $rdr) = @_;
+
+   $self->encoding and $rdr->encoding( $self->encoding );
+
+   return $self->$_read_filter( [ $rdr->chomp->getlines ] );
 }
 
-# Private subroutines
-sub __original_order {
-   my ($hash, $lhs, $rhs) = @_;
+sub write_to_file {
+   my ($self, $wtr, $data) = @_;
 
-   # New elements will be  added at the end
-   exists $hash->{ $lhs }->{_order_by} or return  1;
-   exists $hash->{ $rhs }->{_order_by} or return -1;
-   return $hash->{ $lhs }->{_order_by} <=> $hash->{ $rhs }->{_order_by};
-}
+   $self->encoding and $wtr->encoding( $self->encoding );
+   $wtr->println( @{ $self->$_write_filter( $data ) } );
+
+   return $data;
+};
 
 1;
 
@@ -150,6 +143,10 @@ File::UnixAuth::Storage - Unix authentication and authorisation file storage
 
 =head1 Subroutines/Methods
 
+=head2 read_from_file
+
+=head2 write_to_file
+
 =head1 Diagnostics
 
 =head1 Dependencies
@@ -178,7 +175,7 @@ Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2014 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
